@@ -1,7 +1,7 @@
 //
 // Iterator.cs: Redland Iterator class
 //
-// $Id: Iterator.cs,v 1.9 2005/01/05 11:41:42 edd Exp $
+// $Id: Iterator.cs 10843 2006-04-25 05:26:20Z dajobe $
 //
 // Author:
 //	Cesar Lopez Nataren (cesar@ciencias.unam.mx)
@@ -27,9 +27,6 @@ namespace Redland {
 			get { return handle; }
 		}
 
-		[DllImport ("librdf")]
-		static extern int librdf_iterator_end (HandleRef iterator);
-		
 		[DllImport ("librdf")]
 		static extern IntPtr librdf_iterator_get_object (HandleRef iterator);
 
@@ -41,7 +38,10 @@ namespace Redland {
 			get { 
 				IntPtr raw_ret = librdf_iterator_get_object (handle);
 				// FIXME: throw exception if zero?
-				return new Node (raw_ret);
+				if(raw_ret != IntPtr.Zero)
+					return new Node (raw_ret);
+				else
+					return null;
 			}
 		}
 
