@@ -1,11 +1,10 @@
 //
 // Query.cs - Redland Query class
 //
-// $Id: Query.cs,v 1.6 2005/01/05 11:41:42 edd Exp $
+// $Id: Query.cs 10845 2006-04-25 05:28:51Z dajobe $
 //
-// Copyright (C) 2004 David Beckett - http://purl.org/net/dajobe/
-// Institute for Learning and Research Technology - http://www.ilrt.bris.ac.uk/
-// University of Bristol - http://www.bristol.ac.uk/
+// Copyright (C) 2004-2005 David Beckett - http://purl.org/net/dajobe/
+// Copyright (C) 2004-2005 University of Bristol - http://www.bristol.ac.uk/
 //
 
 using System;
@@ -92,7 +91,11 @@ namespace Redland {
 		{
 			IntPtr raw_qr = librdf_query_execute (handle, model.Handle);
 			// FIXME: throw exception if raw_qr is zero
-			QueryResults qr = new QueryResults (raw_qr);
+			QueryResults qr;
+			if (raw_qr != IntPtr.Zero)
+				qr = new QueryResults (raw_qr);
+			else
+				qr = null;
 			return qr;
 		}
 	}
