@@ -1,9 +1,9 @@
 # 
 # RDF.py - Redland Python RDF module
 #
-# $Id: RDF.py 10943 2006-05-04 05:39:06Z dajobe $
+# $Id: RDF.py 12132 2007-04-23 02:01:34Z dajobe $
 #
-# Copyright (C) 2000-2005 David Beckett - http://purl.org/net/dajobe/
+# Copyright (C) 2000-2006 David Beckett - http://purl.org/net/dajobe/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software and part of Redland http://librdf.org/
@@ -109,7 +109,7 @@ __all__ = [ "Node",
 __version__ = "1.1"
 
 # For pydoc
-__date__ = '$Date: 2006-05-03 22:39:06 -0700 (Wed, 03 May 2006) $'
+__date__ = '$Date: 2007-04-22 19:01:34 -0700 (Sun, 22 Apr 2007) $'
 __author__ = 'Dave Beckett - http://purl.org/net/dajobe, Edd Dumbill <edd@usefulinc.com> and Matt Biddulph <mb@picdiary.com>'
 
 # Package variables [globals]
@@ -142,7 +142,7 @@ class RedlandError(Exception):
 class NodeTypeError(RedlandError):
   pass
 
-class RedlandWarning(RedlandError):
+class RedlandWarning(Warning):
   pass
 
 def node_type(name):
@@ -275,6 +275,10 @@ class Node(object):
       elif type(arg) is Node:
         args['node'] = arg
 
+    if args.has_key('literal') and type(args['literal']) is unicode:
+        import Redland_python
+        args['literal'] = Redland_python.unicode_to_bytes(args['literal'])
+
     if args.has_key('uri_string'):
       self._node=Redland.librdf_new_node_from_uri_string(_world._world,
         args['uri_string'])
@@ -725,11 +729,13 @@ Create a model using an in-memory storage.
     # adding a statement means it gets *copied* into the model
     # we are free to re-use the statement after adding it
     if context is not None:
-      return Redland.librdf_model_context_add_statement(self._model,
+      rc = Redland.librdf_model_context_add_statement(self._model,
               context._node, statement._statement)
     else:
-      return Redland.librdf_model_add_statement(self._model,
+      rc = Redland.librdf_model_add_statement(self._model,
                                                 statement._statement)
+    if rc != 0:
+      raise RedlandError("Adding statement failed")
 
   def add_statements(self,statement_stream,context=None):
     """Add the Stream of Statements to the Model with the optional
@@ -1403,7 +1409,7 @@ class Storage(object):
 
     Create a new RDF Storage using any of these forms
 
-  s1=RDF.Storage(storage_name="name")
+  s1=RDF.Storage(storage_name="name",options_string="")
 
 Create a Storage of the given type.  Currently the built in storage
 names that are always present are 'memory', 'hashes', 'file' and
@@ -1414,14 +1420,14 @@ compiled in.  If storage_name is omitted, it defaults to 'memory'.
 The argument 'name' can be used when the storage needs a name
 to operate, such as used for a filename or URI:
 
-  s1=RDF.Storage(storage_name="file", name='/filename')
+  s1=RDF.Storage(storage_name="file", name='/filename',options_string="")
 
-  s2=RDF.Storage(storage_name="uri", name='http://rdf.example.org/')
+  s2=RDF.Storage(storage_name="uri", name='http://rdf.example.org/',options_string="")
 
 
-The argument options_string allows additional store-specific options
-to be given, some of which are required by certain stores.  This uses
-the following form:
+The required argument options_string allows additional store-specific
+options to be given, some of which are required by certain stores.
+This uses the following form:
 
   s3=RDF.Storage(storage_name="name", name='abc',
                  options_string="key1='value1', key2='value2', ...")
@@ -1454,6 +1460,9 @@ storage_name 'mysql' has options:
   database - required MySQL database name
   user - required MySQL database user
   password - required MySQL database password
+
+stoage name 'sqlite' has options:
+  synchronous - optional value off, normal or full
       
 The other form is:
   s4=RDF.Storage(storage=s1)
@@ -1486,7 +1495,7 @@ and Hash storage:
       self._storage=Redland.librdf_new_storage_from_storage(
           args['storage']._storage)
     else:
-      raise RedlandError("Creating Storage failed - illegal arguments")
+      raise RedlandError("Creating Storage failed - missing storage_name, name or options_string arguments")
 
     if self._storage == "NULL" or self._storage == None:
       self._storage=None
@@ -1673,7 +1682,7 @@ optional.  When any are given, they must all match.
 
     self._parser=Redland.librdf_new_parser(_world._world, name, mime_type, ruri)
     if self._parser is None:
-      raise RedlandError("Failed to create parser "+name)
+      raise RedlandError("Parser construction failed")
 
   def __del__(self):
     global _debug    
@@ -1876,6 +1885,8 @@ class Query(object):
 
     self._query = Redland.librdf_new_query(_world._world, query_language, ruri, querystring, rbase_uri)
     self.result_stream = None
+    if self._query is None:
+      raise RedlandError("Query construction failed")
 
   def __del__(self):
     global _debug    
@@ -1936,8 +1947,10 @@ class QueryResults(object):
     return self
 
   def __len__(self):
-    """Get the number of query results returned so far"""
-    return Redland.librdf_query_results_get_count(self._results)
+    """Get the number of query results returned so far (bindings results)"""
+    if self.is_bindings:
+      return Redland.librdf_query_results_get_count(self._results)
+    return 0
 
   # Iterator method
   def next(self):
@@ -2112,7 +2125,7 @@ class Serializer(object):
   only to local files).
   """
   
-  def __init__(self, name="", mime_type="", uri=None):
+  def __init__(self, name=None, mime_type=None, uri=None):
     """Create an RDF Serializer (constructor).
 
     The arguments name, mime_type and uri are all optional and
@@ -2136,6 +2149,8 @@ class Serializer(object):
 
     self._serializer=Redland.librdf_new_serializer(_world._world, name,
       mime_type, ruri)
+    if self._serializer is None:
+      raise RedlandError("Serializer construction failed")
 
   def __del__(self):
     global _debug    
